@@ -43,6 +43,8 @@ RemoteControl::RemoteControl(QObject *parent) :
     rc_passband_lo = 0;
     rc_passband_hi = 0;
     rc_program_id = "0000";
+    rds_station = QString("");
+    rds_radiotext = QString("");
     rds_status = false;
     signal_level = -200.0;
     squelch_level = -150.0;
@@ -50,6 +52,7 @@ RemoteControl::RemoteControl(QObject *parent) :
     audio_recorder_status = false;
     receiver_running = false;
     hamlib_compatible = false;
+    is_audio_muted = false;
 
     rc_port = DEFAULT_RC_PORT;
     rc_allowed_hosts.append(DEFAULT_RC_ALLOWED_HOSTS);
@@ -364,6 +367,12 @@ void RemoteControl::setAudioGain(float gain)
     audio_gain = gain;
 }
 
+/*! \brief Set audio muted (from mainwindow). */
+void RemoteControl::setAudioMuted(bool muted)
+{
+    is_audio_muted = muted;
+}
+
 /*! \brief Start audio recorder (from mainwindow). */
 void RemoteControl::startAudioRecorder(QString unused)
 {
@@ -417,8 +426,23 @@ void RemoteControl::setRDSstatus(bool enabled)
 {
     rds_status = enabled;
     rc_program_id = "0000";
+    rds_station = "";
+    rds_radiotext = "";
 }
 
+/*! \brief Set RDS program service (station) name. */
+void RemoteControl::setRdsStation(QString name)
+{
+    rds_station = name;
+}
+
+/*! \brief Set RDS Radiotext. */
+void RemoteControl::setRdsRadiotext(QString text)
+{
+    rds_radiotext = text;
+}
+
+
 /*! \brief Convert mode string to enum (DockRxOpt::rxopt_mode_idx)
  *  \param mode The Hamlib rigctld compatible mode string
  *  \return An integer corresponding to the mode.
@@ -737,13 +761,15 @@ QString RemoteControl::cmd_get_func(QStringList cmdlist)
     QString func = cmdlist.value(1, "");
 
     if (func == "?")
-        answer = QString("RECORD DSP RDS\n");
+        answer = QString("RECORD DSP RDS MUTE\n");
     else if (func.compare("RECORD", Qt::CaseInsensitive) == 0)
         answer = QString("%1\n").arg(audio_recorder_status);
     else if (func.compare("DSP", Qt::CaseInsensitive) == 0)
         answer = QString("%1\n").arg(receiver_running);
     else if (func.compare("RDS", Qt::CaseInsensitive) == 0)
         answer = QString("%1\n").arg(rds_status);
+    else if (func.compare("MUTE", Qt::CaseInsensitive) == 0)
+        answer = QString("%1\n").arg(is_audio_muted ? '1' : '0');
     else
         answer = QString("RPRT 1\n");
 
@@ -760,7 +786,7 @@ QString RemoteControl::cmd_set_func(QStringList cmdlist)
 
     if (func == "?")
     {
-        answer = QString("RECORD DSP RDS\n");
+        answer = QString("RECORD DSP RDS MUTE\n");
     }
     else if ((func.compare("RECORD", Qt::CaseInsensitive) == 0) && ok)
     {
@@ -787,6 +813,15 @@ QString RemoteControl::cmd_set_func(QStringList cmdlist)
 
         answer = QString("RPRT 0\n");
     }
+    else if (func.compare("MUTE", Qt::CaseInsensitive) == 0)
+    {
+        if (status)
+            emit newAudioMuted(true);
+        else
+            emit newAudioMuted(false);
+
+        answer = QString("RPRT 0\n");
+    }
     else if ((func.compare("RDS", Qt::CaseInsensitive) == 0) && ok)
     {
         if (status)
@@ -811,9 +846,13 @@ QString RemoteControl::cmd_get_param(QStringList cmdlist)
     QString func = cmdlist.value(1, "");
 
     if (func == "?")
-        answer = QString("RDS_PI\n");
+        answer = QString("RDS_PI RDS_PS_NAME RDS_RADIOTEXT\n");
     else if (func.compare("RDS_PI", Qt::CaseInsensitive) == 0)
         answer = QString("%1\n").arg(rc_program_id);
+    else if (func.compare("RDS_PS_NAME", Qt::CaseInsensitive) == 0)
+        answer = QString("%1\n").arg(rds_station);
+    else if (func.compare("RDS_RADIOTEXT", Qt::CaseInsensitive) == 0)
+        answer = QString("%1\n").arg(rds_radiotext);
     else
         answer = QString("RPRT 1\n");
 
