@@ -92,11 +92,15 @@ public slots:
     void setMode(int mode);
     void setPassband(int passband_lo, int passband_hi);
     void setSquelchLevel(double level);
+    void setAudioGain(float gain);
+    void setAudioMuted(bool muted);
     void startAudioRecorder(QString unused);
     void stopAudioRecorder();
     bool setGain(QString name, double gain);
     void setRDSstatus(bool enabled);
     void rdsPI(QString program_id);
+    void setRdsStation(QString name);
+    void setRdsRadiotext(QString text);
 
 signals:
     void newFrequency(qint64 freq);
@@ -105,11 +109,13 @@ signals:
     void newMode(int mode);
     void newPassband(int passband);
     void newSquelchLevel(double level);
+    void newAudioGain(float gain);
     void startAudioRecorderEvent();
     void stopAudioRecorderEvent();
     void gainChanged(QString name, double value);
     void dspChanged(bool value);
     void newRDSmode(bool value);
+    void newAudioMuted(bool muted);
 
 private slots:
     void acceptConnection();
@@ -133,11 +139,15 @@ private:
     bool        rds_status;        /*!< RDS decoder enabled */
     float       signal_level;      /*!< Signal level in dBFS */
     double      squelch_level;     /*!< Squelch level in dBFS */
+    float       audio_gain;        /*!< Audio gain in dB */
     QString     rc_program_id;     /*!< RDS Program identification */
+    QString     rds_station;       /*!< RDS program service (station) name */
+    QString     rds_radiotext;     /*!< RDS Radiotext */
     bool        audio_recorder_status; /*!< Recording enabled */
     bool        receiver_running;  /*!< Whether the receiver is running or not */
     bool        hamlib_compatible;
     gain_list_t gains;             /*!< Possible and current gain settings */
+    bool        is_audio_muted;
 
     void        setNewRemoteFreq(qint64 freq);
     int         modeStrToInt(QString mode_str);
