@@ -707,7 +707,7 @@ void CIoConfig::inputDeviceSelected(int index)
  *
  * This slot is activated when the device string in the text edit box has changed
  * either by the user or programmatically. We use this to enable/disable the OK
- * button - we allo OK only if there is some text in the text entry.
+ * button - we allow OK only if there is some text in the text entry.
  */
 void CIoConfig::inputDevstrChanged(const QString &text)
 {
@@ -749,10 +749,10 @@ void CIoConfig::decimationChanged(int index)
     quad_rate = (float)input_rate / (float)decim;
     if (quad_rate > 1.e6f)
         ui->sampRateLabel->setText(QString(" %1 Msps").
-                                   arg(quad_rate * 1.e-6, 0, 'f', 3));
+                                   arg((double)quad_rate * 1.e-6, 0, 'f', 3));
     else
         ui->sampRateLabel->setText(QString(" %1 ksps").
-                                   arg(quad_rate * 1.e-3, 0, 'f', 3));
+                                   arg((double)quad_rate * 1.e-3, 0, 'f', 3));
 }
 
 /**
