@@ -70,12 +70,11 @@ public:
     bool stop();
 
     void set_quad_rate(float quad_rate);
-    void set_audio_rate(float audio_rate);
 
     void set_filter(double low, double high, double tw);
     void set_cw_offset(double offset) { (void)offset; }
 
-    float get_signal_level(bool dbfs);
+    float get_signal_level();
 
     /* Noise blanker */
     bool has_nb() { return false; }
